==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AssigningRadialStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialStyleEventArgsDescription } from "./AssigningRadialStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningRadialStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningRadialStyleEventArgsDescriptionMetadata, _super);
    function AssigningRadialStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningRadialStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningRadialStyleEventArgsDescriptionMetadata.a == null) {
            AssigningRadialStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningRadialStyleEventArgsDescriptionMetadata.c(AssigningRadialStyleEventArgsDescriptionMetadata.a);
        }
        if (a.g(AssigningRadialStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(AssigningRadialStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningRadialStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningRadialStyleEventArgsDescriptionMetadata.b(a);
        a.u("AssigningRadialStyleEventArgs", function () { return new AssigningRadialStyleEventArgsDescription(); });
        a.t("AssigningRadialStyleEventArgs", AssigningRadialStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialStyleEventArgsDescriptionMetadata.$t = markType(AssigningRadialStyleEventArgsDescriptionMetadata, 'AssigningRadialStyleEventArgsDescriptionMetadata');
    AssigningRadialStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningRadialStyleEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AssigningRadialStyleEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata";
import { AssigningRadialStyleEventArgsDescription } from "./AssigningRadialStyleEventArgsDescription";
/**
 * @hidden
 */
var AssigningRadialStyleEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningRadialStyleEventArgsDescriptionMetadata, _super);
    function AssigningRadialStyleEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningRadialStyleEventArgsDescriptionMetadata.b = function (a) {
        if (AssigningRadialStyleEventArgsDescriptionMetadata.a == null) {
            AssigningRadialStyleEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningRadialStyleEventArgsDescriptionMetadata.c(AssigningRadialStyleEventArgsDescriptionMetadata.a);
        }
        if (a.j(AssigningRadialStyleEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningRadialStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialStyleEventArgsDescriptionMetadata.c = function (a) {
        AssigningSeriesShapeStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningRadialStyleEventArgsDescriptionMetadata.d = function (a) {
        AssigningRadialStyleEventArgsDescriptionMetadata.b(a);
        a.aa("AssigningRadialStyleEventArgs", function () { return new AssigningRadialStyleEventArgsDescription(); });
        a.z("AssigningRadialStyleEventArgs", AssigningRadialStyleEventArgsDescriptionMetadata.a);
    };
    AssigningRadialStyleEventArgsDescriptionMetadata.$t = markType(AssigningRadialStyleEventArgsDescriptionMetadata, 'AssigningRadialStyleEventArgsDescriptionMetadata');
    AssigningRadialStyleEventArgsDescriptionMetadata.a = null;
    return AssigningRadialStyleEventArgsDescriptionMetadata;
}(Base));
export { AssigningRadialStyleEventArgsDescriptionMetadata };
